@@ -349,7 +349,7 @@ def insert_sql(df, table, schema=None, placeholder="%s"):
     return insert_sql, values
 
 
-def pg_rawload(cnxn, handle, meta_df, dummy_separator="@", table_name=None):
+def pg_rawload(cnxn, handle, meta_df, dummy_separator="\v", table_name=None):
     """Uses psycopg2 methods to load raw data into a one-column table.
 
     Uses default schema; no support for specifying schema inside this function.
@@ -362,13 +362,16 @@ def pg_rawload(cnxn, handle, meta_df, dummy_separator="@", table_name=None):
         Must be a connection created by psycopg2.connect().
     
     handle: required
-        Must be a file-like object. I.e., returned by open(path).
+        Must be a file-like object. I.e., returned by pyhcup.parser._open().
 
     meta_df: required
         Must be a pandas DataFrame with meta data on the file in question. I.e., returned by pyhcup.meta.get().
 
-    dummy_separator: required (default: "@")
-        Must be a character not found in the data to be loaded. The psycopg2.cursor.copy_from() method uses a tab ('\t') by default, which may result in inconsistent loads if found within the data to be loaded. The default pipe character is considered a safe choice, though it has not been exhaustively tested against all HCUP data.
+    dummy_separator: required (default: "\v")
+        Must be a character not found in the data to be loaded. The
+        psycopg2.cursor.copy_from() method uses a horizontal tab ('\t')
+        by default, but I am afraid of occasional horizontal tabs in
+        HCUP and PUDF data that we just haven't found yet.
         
     table_name: optional (default: None)
         Table name for the load. Will be generated automatically if not provided.
