@@ -19,6 +19,21 @@ dir_path = os.path.dirname(path)
 BUNDLED_UFLAGDEF = os.path.join(dir_path, 'data', 'uflags', 'uflag_definitions.csv')
 
 
+# Some files have bonus content, which should be skipped for loading
+SKIP_ROWS = {
+        ('SID', 'AR', 2010, 'AHAL'): 2,
+        ('SID', 'AR', 2010, 'CHGS'): 2,
+        ('SID', 'AR', 2010, 'CORE'): 2,
+        ('SID', 'AR', 2010, 'DX_PR_GRPS'): 2,
+        ('SID', 'AR', 2010, 'SEVERITY'): 2,
+        ('SID', 'AR', 2011, 'AHAL'): 2,
+        ('SID', 'AR', 2011, 'CHGS'): 2,
+        ('SID', 'AR', 2011, 'CORE'): 2,
+        ('SID', 'AR', 2011, 'DX_PR_GRPS'): 2,
+        ('SID', 'AR', 2011, 'SEVERITY'): 2,
+    }
+
+
 # definitions for replacing missing values down the line
 MISSING_PATTERNS = {
         'missing':        '-9*\.?9*[^-\.]| |\.',
@@ -99,6 +114,24 @@ def lm_reverse(category, entry):
     else:
         return False
 
+def _open(full_path, state, year, variety, database='SID'):
+    """Returns a handle using python's builtin open() function; however, it
+    will skip past any non-content rows as specified within.
+    
+    This is necessary because HCUP files very occasionally have bonus
+    content, typically a data use notice, and it mucks up parsing.
+    """
+    
+    handle = open(full_path)
+    
+    screen = (str(database).upper(), str(state).upper(), int(year), str(variety).upper())
+    print screen
+    
+    if screen in SKIP_ROWS:
+        skipped = [handle.readline() for x in xrange(SKIP_ROWS[screen])]
+    
+    return handle
+
 
 def read(target, meta_df=None, state=None, year=None, variety=None,
          skiprows=None, nrows=None, chunksize=None):
@@ -107,8 +140,7 @@ def read(target, meta_df=None, state=None, year=None, variety=None,
     Returns a pandas DataFrame object containing the parsed data if chunksize is None, otherwise returns a reader generating chunksize chunks with each iteration.
     
     target -> required
-        1. full path to a data file (including filename); or
-        2. a file-like Python object (e.g. handler)
+        Must be the full path to a data file
     
     meta_df -> optional
         may be a pandas DataFrame object containing meta data (width and field)
@@ -132,6 +164,8 @@ def read(target, meta_df=None, state=None, year=None, variety=None,
     widths = [int(x) for x in meta_df.width]
     names = [x for x in meta_df.field]
     
+    handle = _open(target, state, year, variety)
+    
     result = pd.read_fwf(target, header=None, widths=widths, names=names,
                          nrows=nrows, skiprows=skiprows, chunksize=chunksize)
     return result
@@ -208,8 +242,10 @@ class UtilizationFlagger:
                 setattr(self, '_' + v, None)
     
     
-    def sql(self, tbl_out, tbl_core, tbl_pr, tbl_charges):
+    def sql(self, tbl_out, tbl_core, tbl_pr, tbl_charges, state='', year='NULL'):
         """Generates a SQL statement for generating values for this selflag within a database.
+        
+        If provided, state should be a string and year should be an integer or the string literal 'NULL'.
         """
         sel_cols = ['t_core.key']
         
@@ -282,7 +318,7 @@ class UtilizationFlagger:
         sel_cols.append(pr_clause)
         
         selflag_sql = """
-            SELECT {cs_sel_clauses}
+            SELECT {cs_sel_clauses}, {state} AS state, {year} AS year
               FROM {tbl_core} AS t_core
               LEFT JOIN {tbl_charges} AS t_revcode
                 ON t_core.key = t_revcode.key
@@ -293,6 +329,8 @@ class UtilizationFlagger:
                        tbl_core=tbl_core,
                        tbl_charges=tbl_charges,
                        tbl_pr=tbl_pr,
+                       state=state,
+                       year=year
                        )
         
         full_sql = """
